native_video_editor library
Classes
- AudioMergeRequest
- Describes a request to merge an audio track into an existing video file.
- ImageVideoComposeRequest
- Describes a request to compose a still image and an audio file into an MP4 video.
- NativeVideoEditor
- Entry point for native video editing operations.
- VideoCropRect
- A normalized crop rectangle for the source video frame.
- VideoEditRequest
- Describes a native video export request.
- VideoThumbnailRequest
- Describes a native thumbnail extraction request.